Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Client ¶
type Client interface {
Connect(context.Context) error
Disconnect(context.Context) error
Database(string) Database
ListDatabaseNames(context.Context, interface{}) ([]string, error)
}
func WrapClient ¶
type Collection ¶
type Collection interface {
Aggregate(context.Context, interface{}, ...*options.AggregateOptions) (Cursor, error)
Find(context.Context, interface{}, ...*options.FindOptions) (Cursor, error)
FindOne(context.Context, interface{}, ...*options.FindOneOptions) SingleResult
Name() string
ReplaceOne(context.Context, interface{}, interface{}, ...*options.ReplaceOptions) (*UpdateResult, error)
UpdateOne(context.Context, interface{}, interface{}, ...*options.UpdateOptions) (*UpdateResult, error)
UpdateMany(context.Context, interface{}, interface{}, ...*options.UpdateOptions) (*UpdateResult, error)
InsertOne(context.Context, interface{}) (*InsertOneResult, error)
InsertMany(context.Context, []interface{}) (*InsertManyResult, error)
}
type InsertManyResult ¶
type InsertManyResult = mongo.InsertManyResult
type InsertOneResult ¶
type InsertOneResult = mongo.InsertOneResult
type MigrationOperation ¶
MigrationOperation defines the function object that performs the transformation in the manual migration migrations. Register these functions using RegisterMigrationOperation.
Implementors of MigrationOperations are responsible for implementing idempotent operations.
type Processor ¶
type Processor interface {
Load(Client, model.Namespace, map[string]interface{}) Cursor
Migrate(Cursor) error
}
Processor defines the process for processing a stream of documents using a Cursor.
type SingleResult ¶
type UpdateResult ¶
type UpdateResult = mongo.UpdateResult
Click to show internal directories.
Click to hide internal directories.